@@ -9,21 +9,21 @@
 // or else upgrading old project file will not work
 // reliably.
 // TODO QGIS 4: remove in favor of _QGIS_VERSION
-#define VERSION "3.38.3-Grenoble"
-#define _QGIS_VERSION "3.38.3-Grenoble"
+#define VERSION "3.44.0-Solothurn"
+#define _QGIS_VERSION "3.44.0-Solothurn"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 3383
+//#define VERSION_INT 3440
 // TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
-#define VERSION_INT 33803
-#define _QGIS_VERSION_INT 33803
-#define ABISYM(x) x ## 33803
+#define VERSION_INT 34400
+#define _QGIS_VERSION_INT 34400
+#define ABISYM(x) x ## 34400
 //used in main.cpp and anywhere else where the release name is needed
-#define RELEASE_NAME "Grenoble"
+#define RELEASE_NAME "Solothurn"
 
 #define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
 #define QGIS_DATA_SUBDIR "share"
@@ -42,13 +42,13 @@
 #define QGIS_MACAPP_BUNDLE 
 #endif
 
-#define PYTHON_VERSION "3.11.10"
+#define PYTHON_VERSION "3.12.11"
 #define PYTHON_VERSION_MAJOR "3"
-#define PYTHON_VERSION_MINOR "11"
-#define PYTHON_VERSION_PATCH "10"
+#define PYTHON_VERSION_MINOR "12"
+#define PYTHON_VERSION_PATCH "11"
 
 #define PROJ_VERSION_MAJOR 9
-#define PROJ_VERSION_MINOR 4
+#define PROJ_VERSION_MINOR 5
 #define PROJ_VERSION_PATCH 1
 
 /* #undef USING_NMAKE */
@@ -88,7 +88,7 @@
 
 /* #undef AGGRESSIVE_SAFE_MODE */
 
-/* #undef HAVE_QUICK */
+#define HAVE_QUICK
 
 #define HAVE_QTSERIALPORT
 
@@ -103,20 +103,20 @@
 #define HAVE_COPC
 
 #define HAVE_PDAL_QGIS
-#define PDAL_VERSION "2.8.0"
+#define PDAL_VERSION "2.9.0"
 #define PDAL_VERSION_MAJOR_INT 2
-#define PDAL_VERSION_MINOR_INT 8
+#define PDAL_VERSION_MINOR_INT 9
 #define PDAL_VERSION_MAJOR "2"
-#define PDAL_VERSION_MINOR "8"
+#define PDAL_VERSION_MINOR "9"
 #define PDAL_VERSION_MICRO "0"
 
 #define HAVE_DRACO
 
 /* #undef ENABLE_TESTS */
 
-#define HAS_KDE_QT5_PDF_TRANSFORM_FIX
-#define HAS_KDE_QT5_SMALL_CAPS_FIX
-#define HAS_KDE_QT5_FONT_STRETCH_FIX
+/* #undef HAS_KDE_QT5_PDF_TRANSFORM_FIX */
+/* #undef HAS_KDE_QT5_SMALL_CAPS_FIX */
+/* #undef HAS_KDE_QT5_FONT_STRETCH_FIX */
 
 /* #undef HAVE_PDF4QT */
 
